import json
import uuid
from typing import Text, Optional, Dict, Any, List

import pytest
from rasax.community.services.event_service import EventService
from rasax.community.tracker_utils import ACTION_SESSION_START_NAME
from tests.unit.conftest import user_event, bot_event, action_event, TEST_USER_TESTER


tag_1 = [{"value": "tag_1_name", "color": "eah45a"}]
tag_2 = [{"value": "tag_2_name", "color": "eah45a"}]
tag_3 = [{"value": "tag_3_name", "color": "eah45a"}]

CONVERSATIONS_ENDPOINT = "/api/conversations"
TAGS_ENDPOINT = "tags"


def generate_conversation(
    event_service: EventService, sender_id: Optional[Text] = None
) -> Text:
    if not sender_id:
        sender_id = uuid.uuid4().hex

    events = [
        action_event(sender_id, 1000, action_name=ACTION_SESSION_START_NAME),
        bot_event(sender_id, 2000),
        user_event(sender_id, 3000),
        bot_event(sender_id, 4000),
        action_event(sender_id, 5000),
    ]

    for event in events:
        event_service.save_event(json.dumps(event), sender_id=sender_id)

    event_service.add_flagged_message(sender_id, 3000)
    event_service.add_flagged_message(sender_id, 5000)

    return sender_id


def get_conversation_by_id(
    all_conversations: List[Dict[Text, Any]], id: Text
) -> Optional[Dict[Text, Any]]:
    for conversation in all_conversations:
        if conversation["sender_id"] == id:
            return conversation
    return None


@pytest.fixture()
def conversation(event_service: EventService) -> Text:
    return generate_conversation(event_service)


@pytest.fixture()
def conversation_other(event_service: EventService) -> Text:
    return generate_conversation(event_service)


@pytest.fixture()
def conversation_for_tester(event_service: EventService) -> Text:
    return generate_conversation(event_service, sender_id=TEST_USER_TESTER)
